# neutralocean
Calculate neutral surfaces in the ocean, using Python

# Installation
To install `neutralocean`, simply execute
```
$ pip install neutralocean
```

Later, `neutralocean` will also be added to conda-forge.


# Usage
Try running the example script:
```
python /path/to/neutralocean/neutralocean/examples/run_OCCA.py
```
If that runs, we're in business.  
Take a look at that example script, `run_OCCA.py` located in `neutralocean/examples/`.
It is documented and will walk you through loading an ocean model dataset, selecting an equation of state, calculating various approximately neutral surfaces, and more. 